==> gimp-1.0.4.tar.bz2: gimp-1.0.4/app/pixmaps.h <==
/*  GIMP icon image format -- S. Kimball, P. Mattis  */
/*  Image name: airbrush  */


#define airbrush_width 22
#define airbrush_height 22
static char *airbrush_bits [] =
{
  "......................",
  "......................",
  "......................",
  "................aaa...",
  "...............aaaae..",
  "..............aaaaae..",
  ".............aaaaaee..",
  "............aaaaaee...",
  ".......aa..aaaaaee....",
  "......aa..aaaaaee.....",
  "......a.aaaaaaee......",
  "........ahaaaee.......",
  ".......ahhgaee........",
  "......ahhgaee.........",
  ".....ahhgaae.....aa...",
  "....ahhgaeea....a.....",
  "....ahgaee.a....a.....",
  "...ahaaee...a..a......",
  "...aaeee.....aa.......",
  "....ee................",
  "......................",
  "......................"
};
/*  GIMP icon image format -- S. Kimball, P. Mattis  */
/*  Image name: bezier  */


#define bezier_width 22
#define bezier_height 22
static char *bezier_bits [] =
{
  "......................",
  "......................",
  "........eaaaaaae......",
  "......aaa......a......",
  ".....a.........ae.....",
  "....a.........aaae....",
  "....a........ahagae...",
  "...a.........ahahae...",
  "...a.........ahahae...",
  "..aaa.......ahgaggae..",
  "..aaae......ahgaggae..",
  "..aaae.....ahgaaaggae.",
  "...aee.....ahgeaeggae.",
  "...a........agggggaee.",
  "...a.........agggaee..",
  "...a.........aaaaae...",
  "...a.........aeaaae...",
  "..a..........aeaaae...",
  "..a..........aeaaae...",
  ".a...........aeaaae...",
  "..............eeeee...",
  "......................"
};
/*  GIMP icon image format -- S. Kimball, P. Mattis  */
/*  Image name: blur  */


#define blur_width 22
#define blur_height 22
static char *blur_bits [] =
{
  "......................",
  "......................",
  "......................",
  "..........e...........",
  "..........e...........",
  ".........ehe..........",
  ".........ehee.........",
  "........ehhge.........",
  "........ehhgee........",
  ".......ehhhgge........",
  "......ehhhhhgge.......",
  "......ehhhhhggee......",
  ".....ehhhhhgggga......",
  ".....ehhhhhggggae.....",
  ".....egghhhggggae.....",
  ".....egggggggggae.....",
  "......agggggggaee.....",
  ".......agggggaee......",
  "........aaaaaee.......",
  ".........eeeee........",
  "......................",
  "......................"
};
/*  GIMP icon image format -- S. Kimball, P. Mattis  */
/*  Image name: circ  */


#define circ_width 22
#define circ_height 22
static char *circ_bits [] =
{
  "......................",
  "......................",
  "......................",
  "......................",
  "........aahha.........",
  "......hhgggggah.......",
  ".....ahgggggggha......",
  ".....aggggggggga......",
  "....hgggggggggggh.....",
  "....agggggggggggh.....",
  "....aggggggggggga.....",
  "....hggggggggggga.....",
  "....hgggggggggggh.....",
  ".....agggggggggh......",
  ".....ahgggggggaa......",
  "......haggggghh.......",
  "........ahhaa.........",
  "......................",
  "......................",
  "......................",
  "......................",
  "......................"
};
/*  GIMP icon image format -- S. Kimball, P. Mattis  */
/*  Image name: clone  */


#define clone_width 22
#define clone_height 22
static char *clone_bits [] =
{
  "......................",
  "......................",
  "......................",
  "........eaaae.........",
  ".......eahhgae........",
  ".......aheeega........",
  ".......ahgggga........",
  ".......aggggga........",
  ".......eagggae........",
  "........eaaae.........",
  ".........aha..........",
  ".....aaaaahaaaaa......",
  "....ahhhhaaahhhha.....",
  "...ahhhhhhhhhhhhha....",
  "...aaaaaaaaaaaaaaae...",
  "...aggggaaaaaggggae...",
  "...agggggaaagggggae...",
  "...aggggggaggggggae...",
  "....aaaaaaaaaaaaaee...",
  ".....eeeeeeeeeeeee....",
  "......................",
  "......................"
};
/*  GIMP icon image format -- S. Kimball, P. Mattis  */
/*  Image name: colorpicker  */


#define colorpicker_width 22
#define colorpicker_height 22
static char *colorpicker_bits [] =
{
  "......................",
  "......................",
  "......................",
  "...............aaa....",
  "..............aaaaa...",
  "..............aaaaae..",
  "...........aaaaaaaae..",
  "............aaaaaaee..",
  "...........ehaaaeee...",
  "..........ehhhaae.....",
  ".........ehhhaeae.....",
  "........ehhhaee.e.....",
  ".......ehhhaee........",
  "......ehhhaee.........",
  ".....ehhhaee..........",
  "....ehhhaee...........",
  "....ehhaee............",
  "...ehaaee.............",
  "....aeee..............",
  ".....e................",
  "......................",
  "......................"
};
/*  GIMP icon image format -- S. Kimball, P. Mattis  */
/*  Image name: crop  */


#define crop_width 22
#define crop_height 22
static char *crop_bits [] =
{
  "......................",
  "......................",
  "......................",
  "................eae...",
  "...............eaaa...",
  "..............eaaae...",
  ".............eaaaee...",
  "............eaaaee....",
  "...........eaaaee.....",
  "..........eaaaee......",
  ".........eaaaee.......",
  "........eaaaee........",
  ".......eaaaee.........",
  "......eaaaee..........",
  ".....eahhae...........",
  "....eahhae............",
  "...eehhae.............",
  "...aaaae..............",
  "......................",
  "......................",
  "......................",
  "......................"
};
/*  GIMP icon image format -- S. Kimball, P. Mattis  */
/*  Image name: erase  */


#define erase_width 22
#define erase_height 22
static char *erase_bits [] =
{
  "......................",
  "......................",
  "......................",
  "......................",
  "......................",
  "......................",
  "..........aaaaaaaa....",
  ".........ahhhhhhaae...",
  "........ahhhhhhagae...",
  ".......ahhhhhhaggae...",
  "......ahhhhhhaggaee...",
  ".....ahhhhhhaggaee....",
  "....ahhhhhhaggaee.....",
  "...aaaaaaaaggaee......",
  "...aggggggagaee.......",
  "...aggggggaaee........",
  "...aaaaaaaaee.........",
  "....eeeeeeee..........",
  "......................",
  "......................",
  "......................",
  "......................"
};
/*  GIMP icon image format -- S. Kimball, P. Mattis  */
/*  Image name: fill  */


#define fill_width 22
#define fill_height 22
static char *fill_bits [] =
{
  "......................",
  "......................",
  ".........ee...........",
  "........eeee..........",
  ".......eeggee.........",
  ".......eegaee.........",
  ".......eeahee.........",
  ".......aahheeaa.......",
  ".......ahhgeegaaa.....",
  "......ahhghaeggaaa....",
  ".....ahhghagaggeaaa...",
  "....ahhghggaggeeaaae..",
  "...ahhghgggggeeaaaae..",
  "...ahghgggggeeaeaaae..",
  "....ahgggggeeaeeaaae..",
  ".....ahgggeeaee.aaae..",
  "......aggeeaee..aaee..",
  ".......aeeaee...aee...",
  "........aaee.....e....",
  ".........ee...........",
  "......................",
  "......................"
};
/*  GIMP icon image format -- S. Kimball, P. Mattis  */
/*  Image name: free  */


#define free_width 22
#define free_height 22
static char *free_bits [] =
{
  "......................",
  "......................",
  "......................",
  "......................",
  ".........aaaaaaa......",
  "......aaaeeeeeeeaa....",
  ".....aeeee.......ea...",
  "....ae............ae..",
  "...ae.............ae..",
  "...ae...........aaee..",
  "...ae........aaaee....",
  "....aaa...aaaeee......",
  "...aa..aaae...........",
  "...a.a.ae.............",
  "....aaa...............",
  "......a...............",
  "......a...............",
  ".....a................",
  "......................",
  "......................",
  "......................",
  "......................"
};
/*  GIMP icon image format -- S. Kimball, P. Mattis  */
/*  Image name: fuzzy  */


#define fuzzy_width 22
#define fuzzy_height 22
static char *fuzzy_bits [] =
{
  "......................",
  "......................",
  "......h...............",
  "....hgagh.............",
  "....ahgha.............",
  "...hgahagh............",
  "...aghahga............",
  "....hagah.............",
  "....aghga.e...........",
  "......a..ege..........",
  "........eghge.........",
  ".........eghge........",
  "..........egaae.......",
  "...........eaaae......",
  "............eaaae.....",
  ".............eaaae....",
  "..............eaaae...",
  "...............eaaae..",
  "................eae...",
  ".................e....",
  "......................",
  "......................"
};
/*  GIMP icon image format -- S. Kimball, P. Mattis  */
/*  Image name: gradient  */


#define gradient_width 22
#define gradient_height 22
static char *gradient_bits [] =
{
  "......................",
  "......................",
  "......................",
  "..eeeeeeeeeeeeeeeeee..",
  "..aaaeeeegggggggghhe..",
  "..aaeaeegegggggghghe..",
  "..aaaeeeegggggggghhe..",
  "..aaeaeegegggggghghe..",
  "..aaaeeeegggggggghhe..",
  "..aaeaeegegggggghghe..",
  "..aaaeeeegggggggghhe..",
  "..aaeaeegegggggghghe..",
  "..aaaeeeegggggggghhe..",
  "..aaeaeegegggggghghe..",
  "..aaaeeeegggggggghhe..",
  "..aaeaeegegggggghghe..",
  "..aaaeeeegggggggghhe..",
  "..aaaaeegegggggghghe..",
  "..eeeeeeeeeeeeeeeeee..",
  "......................",
  "......................",
  "......................"
};
/*  GIMP icon image format -- S. Kimball, P. Mattis  */
/*  Image name: horizflip  */


#define horizflip_width 22
#define horizflip_height 22
static char *horizflip_bits [] =
{
  "......................",
  "......................",
  "......................",
  "......................",
  "......................",
  "......................",
  "......................",
  "......a........a......",
  ".....aa........aa.....",
  "....aaaaaaaaaaaaaa....",
  "...aaaeeeeeeeeeeaaa...",
  "....aaaaaaaaaaaaaaee..",
  ".....aaeeeeeeeeaaee...",
  "......ae.......aee....",
  ".......e........e.....",
  "......................",
  "......................",
  "......................",
  "......................",
  "......................",
  "......................",
  "......................"
};
/*  GIMP icon image format -- S. Kimball, P. Mattis  */
/*  Image name: iscissors  */


#define iscissors_width 22
#define iscissors_height 22
static char *iscissors_bits [] =
{
  "......................",
  ".eaae.....aaa.........",
  ".aaaa...eee.ea........",
  ".aaaa...a....a........",
  ".eaae..ea....aha......",
  "..a....e..ha..hae.....",
  "..a....a..hae.hae.....",
  "..a....a..hae.hae.....",
  "..ee...a...hahaee.....",
  "...a..ee...hahae......",
  "...a..a.....haae......",
  "...a..a.....haae......",
  "...eeea.....haha......",
  ".....a.....haeha......",
  "...........hae.ha.....",
  "..........haee..haa...",
  ".........haae..haeha..",
  "........haeha..haehae.",
  "........haehae..haaee.",
  ".........haaee....ee..",
  "...........ee.........",
  "......................"
};
/*  GIMP icon image format -- S. Kimball, P. Mattis  */
/*  Image name: magnify  */


#define magnify_width 22
#define magnify_height 22
static char *magnify_bits [] =
{
  "......................",
  "......................",
  "......................",
  "...........aaaa.......",
  ".........eaghh.ae.....",
  ".........ahheehhae....",
  "........aghehhhhga....",
  "........ahehhhhhhae...",
  "........ahhhhhhhhae...",
  "........aghhhhhhgae...",
  ".........ahhhhhhaee...",
  "........aaaghhgaee....",
  ".......aaaeaaaaee.....",
  "......aaaee.eeee......",
  ".....aaaee............",
  "....aaaee.............",
  "...aaaee..............",
  "...eaee...............",
  "....ee................",
  "......................",
  "......................",
  "......................"
};
/*  GIMP icon image format -- S. Kimball, P. Mattis  */
/*  Image name: move  */


#define move_width 22
#define move_height 22
static char *move_bits [] =
{
  "......................",
  "......................",
  "......................",
  "..........a...........",
  ".........aaa..........",
  "........aaaaa.........",
  "..........aeee........",
  "..........ae..........",
  ".....a....ae...a......",
  "....aa....ae...aa.....",
  "...aaaaaaaaaaaaaaa....",
  "....aaeeeeaeeeeaaee...",
  ".....ae...ae...aee....",
  "......e...ae....e.....",
  "..........ae..........",
  "........aaaaa.........",
  ".........aaae.........",
  "..........ae..........",
  "..........e...........",
  "......................",
  "......................",
  "......................"
};
/*  GIMP icon image format -- S. Kimball, P. Mattis  */
/*  Image name: new  */


/*
#define new_width 22
#define new_height 22
static char *new_bits [] =
{
  "......................",
  "......................",
  "......................",
  ".....aaaaaaaaa........",
  ".....ahhhhhhhaa.......",
  ".....ahhhhhhhaga......",
  ".....ahhhhhhhagga.....",
  ".....ahhhhhhhaaaae....",
  ".....ahhhhhhhhggae....",
  ".....ahhhhhhhhhhae....",
  ".....ahhhhhhhhhhae....",
  ".....ahhhhhhhhhhae....",
  ".....ahhhhhhhhhhae....",
  ".....ahhhhhhhhhhae....",
  ".....ahhhhhhhhhhae....",
  ".....ahhhhhhhhhhae....",
  ".....ahhhhhhhhhhae....",
  ".....aaaaaaaaaaaae....",
  "......eeeeeeeeeeee....",
  "......................",
  "......................",
  "......................"
};
*/
/*  GIMP icon image format -- S. Kimball, P. Mattis  */
/*  Image name: open  */


/*
#define open_width 22
#define open_height 22
static char *open_bits [] =
{
  "......................",
  "......................",
  "......................",
  "......................",
  "....eaaaae............",
  "...eaggggae...........",
  "...aggggggaaaaaaaae...",
  "...agggggggggggggga...",
  ".aaaaaaaaaaaaaagggae..",
  ".aegegegegegegagggae..",
  "..aegegegegegegaggae..",
  "..agegegegegegeaggae..",
  "...agegegegegegeagae..",
  "...aegegegegegegagae..",
  "...agegegegegegeagae..",
  "....agegegegegegeaae..",
  "....aegegegegegegaae..",
  ".....aaaaaaaaaaaaaae..",
  "......eeeeeeeeeeeeee..",
  "......................",
  "......................",
  "......................"
};
*/
/*  GIMP icon image format -- S. Kimball, P. Mattis  */
/*  Image name: paint  */


#define paint_width 22
#define paint_height 22
static char *paint_bits [] =
{
  "......................",
  "......................",
  "......................",
  ".............aggae....",
  ".............aggae....",
  "............aggaee....",
  "............aggae.....",
  "...........aggaee.....",
  "...........aggae......",
  "..........aggaee......",
  "..........aggae.......",
  ".........aaaaee.......",
  "........aggaae........",
  ".......ahhgaae........",
  ".......ahgeaae........",
  "......ahgeaaee........",
  "......ageaaee.........",
  ".....aheaaee..........",
  "....aaaaeee...........",
  ".....eeee.............",
  "......................",
  "......................"
};
/*  GIMP icon image format -- S. Kimball, P. Mattis  */
/*  Image name: pencil  */


#define pencil_width 22
#define pencil_height 22
static char *pencil_bits [] =
{
  "......................",
  "......................",
  "......................",
  "..........aaaa........",
  "..........aggga.......",
  ".........aggggae......",
  ".........aaggaee......",
  "........ahhaaae.......",
  "........ahggaee.......",
  ".......ahhggae........",
  ".......ahggaee........",
  "......ahhggae.........",
  "......ahggaee.........",
  "......aaggae..........",
  "......aaaaee..........",
  "......aaaee...........",
  "......aaee............",
  "......aee.............",
  ".......e..............",
  "......................",
  "......................",
  "......................"
};
/*  GIMP icon image format -- S. Kimball, P. Mattis  */
/*  Image name: perspective  */


/*
#define perspective_width 22
#define perspective_height 22
static char *perspective_bits [] =
{
  "......................",
  "......................",
  "......................",
  "......aaaaaaaaa.......",
  ".....eegggggggee......",
  ".....aegggggggea......",
  "....agegggggggega.....",
  "....agegggggggega.....",
  "...eagegggggggegae....",
  "...aggeeeeeeeeegga....",
  "...aggggggggggggga....",
  "..eagagagggggagagae...",
  "..aggaagggggggaagga...",
  "..aggaaagggggaaagga...",
  ".aegggggggggggggggea..",
  ".aaaaaaaaaaaaaaaaaaa..",
  "......................",
  "......................",
  "......................",
  "......................",
  "......................",
  "......................"
};
*/
/*  GIMP icon image format -- S. Kimball, P. Mattis  */
/*  Image name: rect  */


#define rect_width 22
#define rect_height 22
static char *rect_bits [] =
{
  "......................",
  "......................",
  "......................",
  "......................",
  "......................",
  "....aahhaahhaahha.....",
  "....hggggggggggga.....",
  "....hgggggggggggh.....",
  "....agggggggggggh.....",
  "....aggggggggggga.....",
  "....hggggggggggga.....",
  "....hgggggggggggh.....",
  "....agggggggggggh.....",
  "....aggggggggggga.....",
  "....hggggggggggga.....",
  "....haahhaahhaahh.....",
  "......................",
  "......................",
  "......................",
  "......................",
  "......................",
  "......................"
};
/*  GIMP icon image format -- S. Kimball, P. Mattis  */
/*  Image name: rotate  */


/*
#define rotate_width 22
#define rotate_height 22
static char *rotate_bits [] =
{
  "......................",
  "......................",
  ".aaaaaaaaaaa...aaa....",
  ".aeeeeeeeeea..a...a.a.",
  ".aeeeeeeeeea.......aa.",
  ".aeeeeeeeeea......aaa.",
  ".aeeeeeeeeeaae........",
  ".aeeeeeeeeeggae.......",
  ".aeeeeeeeegeggae......",
  ".aeeeeeeeggegggae.....",
  ".aeeeeeegggeggggae....",
  ".aaaaaageeeegggggae...",
  ".....eagggggggggggae..",
  ".....agggggggggggggae.",
  ".....eagggggggggggaee.",
  "......eagggggggggaee..",
  ".......eagggggggaee...",
  ".aaa....eagggggaee....",
  ".aa......eagggaee.....",
  ".a.a...a..eagaee......",
  "....aaa....eaee.......",
  "............ee........"
};
*/
/*  GIMP icon image format -- S. Kimball, P. Mattis  */
/*  Image name: scale  */


#define scale_width 22
#define scale_height 22
static char *scale_bits [] =
{
  "......................",
  "......................",
  "..aaaaaaa.............",
  "..aeeeeeaeaeaea.......",
  "..aeeeeeaggggge.......",
  "..aeeggggaaaaaaaaaa...",
  "..aeegggegggggegggae..",
  "..aaageeegggggagggae..",
  "...egaggggggggegggae..",
  "...agaggggggggegggae..",
  "...egagggggggaggggae..",
  "...aeaeaeaeaegagagae..",
  ".....agggggggggaagae..",
  ".....aggggggggaaagae..",
  ".....aggggggggggggae..",
  ".....aaaaaaaaaaaaaae..",
  "......eeeeeeeeeeeeee..",
  "......................",
  "......................",
  "......................",
  "......................",
  "......................"
};
/*  GIMP icon image format -- S. Kimball, P. Mattis  */
/*  Image name: sharpen  */


/*
#define sharpen_width 22
#define sharpen_height 22
static char *sharpen_bits [] =
{
  "......................",
  "......................",
  "......................",
  "..........a...........",
  "..........ae..........",
  ".........eha..........",
  ".........eha..........",
  ".........ehae.........",
  "........ehgga.........",
  "........ehgga.........",
  "........ehggae........",
  ".......ehgggga........",
  ".......ehgggga........",
  ".......ehggggae.......",
  "......ehhggggga.......",
  "......ehggggggae......",
  "......ehggggggae......",
  ".....ehhgggggeeae.....",
  "......aaaaaaaaaee.....",
  ".......eeeeeeeee......",
  "......................",
  "......................"
};
*/
/*  GIMP icon image format -- S. Kimball, P. Mattis  */
/*  Image name: skew  */


/*
#define skew_width 22
#define skew_height 22
static char *skew_bits [] =
{
  "......................",
  "......................",
  "......................",
  "......................",
  "...aaaaaaaaaaa........",
  "...agggggggggea.......",
  "...aeggggggggega......",
  "...aeggggggggega......",
  "...aeegggggggegga.....",
  "...aeegggggggegga.....",
  "...aeeeggggggeggga....",
  "...aeeeggggggeggga....",
  "...aeeeegggggegggga...",
  "...aaaaageeeeegggga...",
  "........agggggggggga..",
  ".....a...aaaaaaaaaaa..",
  "..aaaaa...............",
  ".....a................",
  "......................",
  "......................",
  "......................",
  "......................"
};
*/
/*  GIMP icon image format -- S. Kimball, P. Mattis  */
/*  Image name: text  */


#define text_width 22
#define text_height 22
static char *text_bits [] =
{
  "......................",
  "......................",
  "......................",
  "......................",
  ".....aaaaaaaaaaa......",
  ".....aaeeaaaeeaae.....",
  ".....aee.aaae..ae.....",
  "......e..aaae...e.....",
  "........eaae..........",
  "........eaae..........",
  "........eaae..........",
  "........aaae..........",
  "........aae...........",
  ".......eaae...........",
  ".......eaae...........",
  ".......aaae...........",
  "......aaaaa...........",
  ".......eeeee..........",
  "......................",
  "......................",
  "......................",
  "......................"
};
/*  GIMP icon image format -- S. Kimball, P. Mattis  */
/*  Image name: vertflip  */


/*
#define vertflip_width 22
#define vertflip_height 22
static char *vertflip_bits [] =
{
  "......................",
  "......................",
  "......................",
  "..........a...........",
  ".........aaa..........",
  "........aaaaa.........",
  ".......aaaeaaa........",
  ".........aeaeee.......",
  ".........aeae.........",
  ".........aeae.........",
  ".........aeae.........",
  ".........aeae.........",
  ".........aeae.........",
  ".........aeae.........",
  ".........aeae.........",
  ".......aaaeaaa........",
  "........aaaaaee.......",
  ".........aaaee........",
  "..........aee.........",
  "...........e..........",
  "......................",
  "......................"
};
*/
/*  GIMP icon image format -- S. Kimball, P. Mattis  */
/*  Image name: default  */


#define default_width 13
#define default_height 13
static char *default_bits [] =
{
  ".............",
  "eeeeeeee.....",
  "eaaaaaae.....",
  "eaaaaaae.....",
  "eaaaaaae.....",
  "eaaaaaaeeeee.",
  "eaaaaaaehhhe.",
  "eaaaaaaehhhe.",
  "eeeeeeeehhhe.",
  "....ehhhhhhe.",
  "....ehhhhhhe.",
  "....ehhhhhhe.",
  "....eeeeeeee."
};
/*  GIMP icon image format -- S. Kimball, P. Mattis  */
/*  Image name: swap  */


#define swap_width 13
#define swap_height 13
static char *swap_bits [] =
{
  "...e.........",
  "..eae........",
  ".eaaeee......",
  "eaaaaaae.....",
  ".eaaeeeae....",
  "..eae..eae...",
  "...e....eae..",
  "........eae..",
  ".......eeaee.",
  "......eaaaaae",
  ".......eaaae.",
  "........eae..",
  ".........e..."
};

==> gimp-1.2.5.tar.bz2: gimp-1.2.5/app/pixmaps.h <==
/*  GIMP icon image format -- S. Kimball, P. Mattis  */
/*  Image name: default  */


#define default_width 13
#define default_height 13
static char *default_bits [] =
{
  ".............",
  "eeeeeeee.....",
  "eaaaaaae.....",
  "eaaaaaae.....",
  "eaaaaaae.....",
  "eaaaaaaeeeee.",
  "eaaaaaaehhhe.",
  "eaaaaaaehhhe.",
  "eeeeeeeehhhe.",
  "....ehhhhhhe.",
  "....ehhhhhhe.",
  "....ehhhhhhe.",
  "....eeeeeeee."
};
/*  GIMP icon image format -- S. Kimball, P. Mattis  */
/*  Image name: swap  */


#define swap_width 13
#define swap_height 13
static char *swap_bits [] =
{
  "...e.........",
  "..eae........",
  ".eaaeee......",
  "eaaaaaae.....",
  ".eaaeeeae....",
  "..eae..eae...",
  "...e....eae..",
  "........eae..",
  ".......eeaee.",
  "......eaaaaae",
  ".......eaaae.",
  "........eae..",
  ".........e..."
};

/* FIXME dialog is basically a temporary pixmap so the device status
 * window doesn't have problems showing the dialog devices, it doesn't
 * really represent anything and really should be changed
 */

/*  GIMP icon image format -- S. Kimball, P. Mattis  */
/*  Image name: dialog  */
#define dialog_width 22
#define dialog_height 22
static char *dialog_bits [] =
{
  "......................",
  "......................",
  "......................",
  "......................",
  "........aaaaa.........",
  "......aagggggaa.......",
  ".....aaggh.gggaa......",
  ".....agggh.eggga......",
  "....aggggh.egggga.....",
  "....aghhhh.ehhhga.....",
  "....ag.........ga.....",
  "....aggeee.eeeega.....",
  "....aggggh.egggga.....",
  ".....agggh.eggga......",
  ".....aaggg.eggaa......",
  "......aagggggaa.......",
  "........aaaaa.........",
  "......................",
  "......................",
  "......................",
  "......................",
  "......................"
};
